using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using System.Drawing.Drawing2D;

namespace Set
{
	public delegate void CardClickedDelegate(CCard self);

	/// <summary>
	/// Summary description for CCard.
	/// </summary>
	public class CCard : System.Windows.Forms.UserControl
	{
		/// <summary> 
		/// Required designer variable.
		/// </summary>
		public event CardClickedDelegate CardClicked;

		private System.ComponentModel.Container components = null;
		private int m_Count;
		private CShape m_Shape;
		private HatchStyle m_HatchStyle;
		private Color m_Color;
		private int m_Size;
		private bool m_Selected;

		public CCard(int Count, CShape Shape, HatchStyle NewHatchStyle, Color NewColor)
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();

			BackColor = Color.White;
			m_Selected = false;
			m_Color = NewColor;
			m_Shape = Shape;
			m_HatchStyle = NewHatchStyle;
			m_Count = Count;
		}

		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			// 
			// CCard
			// 
			this.Name = "CCard";
			this.Size = new System.Drawing.Size(64, 96);
			this.Click += new System.EventHandler(this.CCard_Click);
			this.Paint += new System.Windows.Forms.PaintEventHandler(this.CCard_Paint);

		}
		#endregion

		private void DrawBoarder(Graphics g)
		{
			Pen p = new Pen(Color.Black, 5);
			g.DrawRectangle(p, 0,0,Width,Height);
		}
	
		private void DrawShape(Graphics g)
		{
			m_Size = Height / 3 - 5;
			HatchBrush b = new HatchBrush(m_HatchStyle,m_Color);
			int Left = (Width/2) - (m_Size/2);
			for (int i = 0; i < m_Count; i++)
				m_Shape.Draw(g,b,Left, ((m_Size  + 5) * i + 3) , m_Size);
		}

		private void CCard_Paint(object sender, System.Windows.Forms.PaintEventArgs e)
		{
			DrawBoarder(e.Graphics);
			DrawShape(e.Graphics);
		}

		private void CCard_Click(object sender, System.EventArgs e)
		{
			Selected = !m_Selected;
			CardClicked(this);
		}

		public bool Selected
		{
			get 
			{
				return m_Selected;
			}
			set
			{
				m_Selected = value;

				if (m_Selected)
				{
					BackColor = Color.LightBlue;
				}
				else
				{
					BackColor = Color.White;
				}
			}
		}

		public int Count
		{
			get
			{
				return m_Count;
			}
		}

		public Color Color
		{
			get
			{
				return m_Color;
			}
		}

		public HatchStyle Hatch
		{
			get
			{
				return m_HatchStyle;
			}
		}

		public CShape Shape
		{
			get
			{
				return m_Shape;
			}
		}

//		public Color BackColor
//		{
//		}
	}
}
